@@ -4,12 +4,19 @@
 __author__ = 'yarnaid'
 
 import properties
-# import ext.angles as angles
 from ext.angles import Zone, Angle
 from pixelmap import gPixelMap as PixelMap
-# from alm import Alm
 from pointsource import PointSource
 from tools import convertion as convert
-# from tools import tools
 from tools import colorer
 from tools.logger import logger
+import tools.tools
+import os
+from cl import Cl
+
+
+mappat_path = os.path.join(tools.tools.glesp_exec, tools.tools.glesp['mappat'])
+if not os.path.exists(mappat_path):
+    raise ImportError('Cannot import module {}. No mappat binary found in {}'.format(
+        __name__, tools.tools.glesp_exec
+    ))
\ No newline at end of file
