@@ -3,18 +3,19 @@ __author__ = 'yarnaid'
 try:
     import glespy.pointsource as pointsource
     import glespy.test_data.data as data
-    import glespy.pixelmap as pixelmap
+    # import glespy.pixelmap as pixelmap
 except:
     import pointsource
     import test_data.data as data
-    import pixelmap
+    # import pixelmap
 
 import unittest
 
 
 class PointSourceTest(unittest.TestCase, data.WithTestData):
+
     def setUp(self):
-        super().setUp()
+        super(PointSourceTest, self).setUp()
         self.init_data()
 
     def test_to_pixelmap_with_nx(self):
