@@ -8,6 +8,7 @@ alm_name = 'alm.fit'
 alm_100_name = 'alm_100.fit'
 mask_name = 'mask.fit'
 points_name = 'points.dat'
+cl_name = 'ilc_cl.txt'
 
 
 class WithTestData(object):
@@ -32,4 +33,5 @@ class WithTestData(object):
         self.alm_100_name = os.path.join(self.data_path, alm_100_name)
         self.mask_name = os.path.join(self.data_path, mask_name)
         self.points_name = os.path.join(self.data_path, points_name)
+        self.cl_name = os.path.join(self.data_path, cl_name)
         pass  # todo: init maps with certain parameters
